@@ -1,14 +1,14 @@
 from __future__ import annotations
+
 from bisect import bisect_left
 from functools import lru_cache
-from typing import Any, Dict, List, Optional, Set, Tuple, Union, TYPE_CHECKING
+from typing import Dict, List, Optional
 
-from .constants import ZERGLING
-from .data import Attribute, Race
-from .dicts.unit_trained_from import UNIT_TRAINED_FROM
-from .ids.ability_id import AbilityId
-from .ids.unit_typeid import UnitTypeId
-from .unit_command import UnitCommand
+from sc2.data import Attribute, Race
+from sc2.dicts.unit_trained_from import UNIT_TRAINED_FROM
+from sc2.ids.ability_id import AbilityId
+from sc2.ids.unit_typeid import UnitTypeId
+from sc2.unit_command import UnitCommand
 
 # Set of parts of names of abilities that have no cost
 # E.g every ability that has 'Hold' in its name is free
@@ -48,7 +48,7 @@ class GameData:
                 continue
 
             if unit.creation_ability == ability:
-                if unit.id == ZERGLING:
+                if unit.id == UnitTypeId.ZERGLING:
                     # HARD CODED: zerglings are generated in pairs
                     return Cost(unit.cost.minerals * 2, unit.cost.vespene * 2, unit.cost.time)
                 # Correction for morphing units, e.g. orbital would return 550/0 instead of actual 150/0
@@ -242,7 +242,8 @@ class UnitTypeData:
         # Morphing units
         supply_cost = self._proto.food_required
         if supply_cost > 0 and self.id in UNIT_TRAINED_FROM and len(UNIT_TRAINED_FROM[self.id]) == 1:
-            for producer in UNIT_TRAINED_FROM[self.id]:  # type: UnitTypeId
+            producer: UnitTypeId
+            for producer in UNIT_TRAINED_FROM[self.id]:
                 producer_unit_data = self._game_data.units[producer.value]
                 if 0 < producer_unit_data._proto.food_required <= supply_cost:
                     if producer == UnitTypeId.ZERGLING:
@@ -305,7 +306,6 @@ class Cost:
     The cost of an action, a structure, a unit or a research upgrade.
     The time is given in frames (22.4 frames per game second).
     """
-
     def __init__(self, minerals: int, vespene: int, time: float = None):
         """
         :param minerals:
